#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['drf_info_endpoint']

package_data = \
{'': ['*']}

install_requires = \
['drf-spectacular>=0.17.2', 'django>=3.2', 'djangorestframework>=3.10.0']

setup(name='drf_info_endpoint',
      version='0.0.1',
      description='Django Rest Framework Project Info View',
      author='Viacheslav Krachkov',
      author_email='vskrachkov@gmail.com',
      url='https://github.com/vskrachkov/drf_info_endpoint',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      python_requires='>=3.9',
     )



from django.conf import settings
from drf_spectacular.utils import extend_schema
from rest_framework.decorators import api_view, permission_classes
from rest_framework.permissions import AllowAny
from rest_framework.request import Request
from rest_framework.response import Response

from .serializers import InfoSerializer


@extend_schema(request=None, responses=InfoSerializer())
@api_view(["get"])
@permission_classes([AllowAny])
def info(request: Request) -> Response:
    return Response(
        {
            "app": getattr(settings, "DRF_INFO_ENDPOINT_PROJECT_NAME", "Project"),
            "version": getattr(settings, "DRF_INFO_ENDPOINT_VERSION", "v0.0.0"),
        }
    )
